@@ -546,7 +546,7 @@ def cbindMatrices(hm, args):
         # Add on additional NA initialized columns
         ncol = hm.matrix.matrix.shape[1]
         hm.matrix.matrix = np.hstack((hm.matrix.matrix, np.empty(hm2.matrix.matrix.shape)))
-        hm.matrix.matrix[:, ncol:] = np.NAN
+        hm.matrix.matrix[:, ncol:] = np.nan
 
         # Update the values
         for idx2, group in enumerate(hm2.parameters["group_labels"]):
