@@ -3,10 +3,7 @@
 
 import argparse
 import sys
-try:  # keep python 3.7 support.
-    from importlib.metadata import version
-except ModuleNotFoundError:
-    from importlib_metadata import version
+from importlib.metadata import version
 
 
 def parse_arguments(args=None):
